<?php
if(!defined('INITIALIZED'))
	die('Brak dostepu.');

class Pracownik extends Osoba
{
	protected static $table = 'pracownik';
	protected static $fields = array('stanowisko', 'login', 'haslo');

    public function __construct($id = null)
    {
		if($id != null && $id != 0)
			$this->load($id, 'id');
    }

	public static function getFieldsList()
	{
		if(get_parent_class() && method_exists(get_parent_class(), 'getFieldsList'))
		{
			return array_merge(parent::getFieldsList(), self::$fields);
		}
		else
		{
			return self::$fields;
		}
	}

	public static function create($imie, $nazwisko, $ulica, $kodPocztowy, $miejscowosc, $telefon, $stanowisko, $login, $haslo)
    {
		$pracownik = new Pracownik();
		$pracownik->setImie($imie);
		$pracownik->setNazwisko($nazwisko);
		$pracownik->setUlica($ulica);
		$pracownik->setKodPocztowy($kodPocztowy);
		$pracownik->setMiejscowosc($miejscowosc);
		$pracownik->setTelefon($telefon);
		$pracownik->setStanowisko($stanowisko);
		$pracownik->setLogin($login);
		$pracownik->setHaslo($haslo);
		$pracownik->save();
		return $pracownik;
    }

	public function loadById($id)
	{
		$this->load($id, 'id');
	}

	public function loadByLogin($login)
	{
		$this->load($login, 'login');
	}

	private static function hashPassword($password)
	{
		return sha1($password . sha1($password));
	}
	
	public function isValidPassword($password)
	{
		return self::hashPassword($password) == $this->data['haslo'];
	}


// powiazania
	public function getListPrzesylkaOdebrana()
	{
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('Obiekt nie istnieje.');
		}
		$listPrzesylka = new DatabaseList('PrzesylkaOdebrana');
		$filter = new SQL_Filter(new SQL_Field('pracownik_id'), SQL_Filter::EQUAL, $this->getId());
		$listPrzesylka->setFilter($filter);
		return $listPrzesylka;
	}

	public function dodajPrzesylkaOdebrana(PrzesylkaOdebrana $przesylka)
	{
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('Obiekt $this nie istnieje.');
		}
		if(!$przesylkaOdebrana->isLoaded())
		{
			throw new InvalidArgumentException('PrzesylkaOdebrana nie istnieje.');
		}
		$przesylkaPracownik = $przesylkaOdebrana->getPracownik();
		if($przesylkaPracownik->getId() != $this->getId())
		{
			$przesylkaOdebrana->setPracownik($this);
			$przesylkaOdebrana->save();
		}
	}

	public function getListPrzesylkaNadana()
	{
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('Obiekt nie istnieje.');
		}
		$listPrzesylka = new DatabaseList('PrzesylkaNadana');
		$filter = new SQL_Filter(new SQL_Field('pracownik_id'), SQL_Filter::EQUAL, $this->getId());
		$listPrzesylka->setFilter($filter);
		return $listPrzesylka;
	}

	public function dodajPrzesylkaNadana(PrzesylkaNadana $przesylkaNadana)
	{
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('Obiekt $this nie istnieje.');
		}
		if(!$przesylkaNadana->isLoaded())
		{
			throw new InvalidArgumentException('PrzesylkaNadana nie istnieje.');
		}
		$przesylkaPracownik = $przesylkaNadana->getPracownik();
		if($przesylkaPracownik->getId() != $this->getId())
		{
			$przesylkaNadana->setPracownik($this);
			$przesylkaNadana->save();
		}
	}


// atrybuty

	public function getStanowisko()
	{
		return $this->data['stanowisko'];
	}

	public function setStanowisko($value)
	{
		if(!Stanowisko::isValidValue($value))
		{
			throw new InvalidArgumentException('Nie poprawna wartosc stanowiska.');
		}
		$this->data['stanowisko'] = $value;
	}

	public function getLogin()
	{
		return $this->data['login'];
	}

	public function setLogin($value)
	{
		if($value != (string) $value || strlen($value) > 255)
		{
			throw new InvalidArgumentException('Nie poprawny format loginu.');
		}
		$this->data['login'] = $value;
	}

	public function getHaslo()
	{
		return $this->data['haslo'];
	}

	public function setHaslo($value)
	{
		if($value != (string) $value)
		{
			throw new InvalidArgumentException('Nie poprawny format hasla.');
		}
		$this->data['haslo'] = self::hashPassword($value);
	}
}