<?php
if(!defined('INITIALIZED'))
	die('Brak dostepu.');

class PrzesylkaOdebrana extends Przesylka
{
	protected static $table = 'przesylka_odebrana';
	protected static $fields = array('data_odebrania');

    public function __construct($id = null)
    {
		if($id != null && $id != 0)
			$this->load($id, 'id');
    }

	public static function getFieldsList()
	{
		if(get_parent_class() && method_exists(get_parent_class(), 'getFieldsList'))
		{
			return array_merge(parent::getFieldsList(), self::$fields);
		}
		else
		{
			return self::$fields;
		}
	}

	public static function create(Pracownik $pracownik, $imie, $nazwisko, $ulica, $kodPocztowy, $miejscowosc, $telefon, $opisZawartosci, $dataOdebrania)
    {
		$przesylka = new PrzesylkaOdebrana();
		$przesylka->setPracownik($pracownik);
		$przesylka->setImie($imie);
		$przesylka->setNazwisko($nazwisko);
		$przesylka->setUlica($ulica);
		$przesylka->setKodPocztowy($kodPocztowy);
		$przesylka->setMiejscowosc($miejscowosc);
		$przesylka->setTelefon($telefon);
		$przesylka->setOpisZawartosci($opisZawartosci);
		$przesylka->setDataOdebrania($dataOdebrania);
		$przesylka->save();
		return $przesylka;
    }

// powiazania
	public function getListTransakcja()
	{
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('PrzesylkaOdebrana nie istnieje.');
		}
		$listTransakcja = new DatabaseList('Transakcja');
		$filterTransakcja = new SQL_Filter(new SQL_Field('transakcja_id', 'transakcja_przesylka_odebrana'), SQL_Filter::EQUAL, new SQL_Field('id', 'transakcja'));
		$filterPrzesylka = new SQL_Filter(new SQL_Field('przesylka_id', 'transakcja_przesylka_odebrana'), SQL_Filter::EQUAL, $this->getId());
		$filter = new SQL_Filter($filterTransakcja, SQL_Filter::CRITERIUM_AND, $filterPrzesylka);
		$listTransakcja->setFilter($filter);
		return $listTransakcja;
	}

	public function powiazTransakcja(Transakcja $transakcja)
	{
		if(!$transakcja->isLoaded())
		{
			throw new InvalidArgumentException('Transakcja nie istnieje.');
		}
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('PrzesylkaOdebrana nie istnieje.');
		}
		if(Website::getDatabaseHandler()->query('SELECT ' . Website::getDatabaseHandler()->fieldName('transakcja_id') . ', ' . Website::getDatabaseHandler()->fieldName('przesylka_id') . ' FROM ' . Website::getDatabaseHandler()->tableName('transakcja_przesylka_odebrana') . ' WHERE ' . Website::getDatabaseHandler()->fieldName('transakcja_id') . ' = ' . Website::getDatabaseHandler()->quote($transakcja->getId()) . ' AND ' . Website::getDatabaseHandler()->fieldName('przesylka_id') . ' = ' . Website::getDatabaseHandler()->quote($this->getId()))->fetch() === FALSE)
		{
			Website::getDatabaseHandler()->query('INSERT INTO ' . Website::getDatabaseHandler()->tableName('transakcja_przesylka_odebrana') . ' (' . Website::getDatabaseHandler()->fieldName('transakcja_id') . ', ' . Website::getDatabaseHandler()->fieldName('przesylka_id') . ') VALUES (' . Website::getDatabaseHandler()->quote($transakcja->getId()) . ', ' . Website::getDatabaseHandler()->quote($this->getId()) . ')');
		}
	}

	public function odwiazTransakcja(Transakcja $transakcja)
	{
		if(!$transakcja->isLoaded())
		{
			throw new InvalidArgumentException('Transakcja nie istnieje.');
		}
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('PrzesylkaOdebrana nie istnieje.');
		}
        Website::getDatabaseHandler()->query('DELETE FROM ' . Website::getDatabaseHandler()->tableName('transakcja_przesylka_odebrana') . ' WHERE ' . Website::getDatabaseHandler()->fieldName('transakcja_id') . ' = ' . Website::getDatabaseHandler()->quote($transakcja->getId()) . ' AND ' . Website::getDatabaseHandler()->fieldName('przesylka_id') . ' = ' . Website::getDatabaseHandler()->quote($this->getId()));
	}


// atrybuty
	public function getDataOdebrania()
	{
		return $this->data['data_odebrania'];
	}

	public function setDataOdebrania($value)
	{
		if($value != (int) $value || $value <= 0)
		{
			throw new InvalidArgumentException('Nie poprawny format daty odebrania.');
		}
		$this->data['data_odebrania'] = $value;
	}
}