<?php
if(!defined('INITIALIZED'))
	die('Brak dostepu.');

class Transakcja extends Model
{
	protected static $table = 'transakcja';
	protected static $fields = array('aukcja_id', 'klient_id', 'ilosc_sztuk', 'data_rozpoczecia', 'data_zakonczenia', 'status_transakcji');

    public function __construct($id = null)
    {
		if($id != null && $id != 0)
			$this->load($id, 'id');
    }

	public static function getFieldsList()
	{
		if(get_parent_class() && method_exists(get_parent_class(), 'getFieldsList'))
		{
			return array_merge(parent::getFieldsList(), self::$fields);
		}
		else
		{
			return self::$fields;
		}
	}

	public static function create($iloscSztuk, Aukcja $aukcja, Klient $klient)
    {
		$transakcja = new Transakcja();
		$transakcja->setAukcja($aukcja);
		$transakcja->setKlient($klient);
		$transakcja->setIloscSztuk($iloscSztuk);
		$transakcja->setDataRozpoczecia(time());
		$transakcja->setDataZakonczenia(0);
		$transakcja->setStatusTransakcji(StatusTransakcji::KUPIONA);
		$transakcja->save();
		return $transakcja;
    }


// powiazania
	public function getAukcja()
	{
		return new Aukcja($this->data['aukcja_id']);
	}

	public function setAukcja(Aukcja $value)
	{
		if(!$value->isLoaded())
		{
			throw new InvalidArgumentException('Aukcja nie istnieje.');
		}
		$this->data['aukcja_id'] = $value->getId();
	}

	public function getKlient()
	{
		return new Klient($this->data['klient_id']);
	}

	public function setKlient(Klient $value)
	{
		if(!$value->isLoaded())
		{
			throw new InvalidArgumentException('Klient nie istnieje.');
		}
		$this->data['klient_id'] = $value->getId();
	}

	public function getPowiazaniaPlatnoscAllegro()
	{
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('Transakcja nie istnieje.');
		}
		$listPlatnosc = new DatabaseList('PlatnoscAllegro');
		$filterTransakcja = new SQL_Filter(new SQL_Field('transakcja_id', 'transakcja_platnosc_allegro'), SQL_Filter::EQUAL, $this->getId());
		$filterPlatnosc = new SQL_Filter(new SQL_Field('platnosc_id', 'transakcja_platnosc_allegro'), SQL_Filter::EQUAL, new SQL_Field('id', 'platnosc_allegro'));
		$filter = new SQL_Filter($filterTransakcja, SQL_Filter::CRITERIUM_AND, $filterPlatnosc);
		$listPlatnosc->setFilter($filter);
		return $listPlatnosc;
	}

	public function powiazPlatnoscAllegro(PlatnoscAllegro $platnosc)
	{
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('Transakcja nie istnieje.');
		}
		if(!$platnosc->isLoaded())
		{
			throw new InvalidArgumentException('PlatnoscAllegro nie istnieje.');
		}
		if(Website::getDatabaseHandler()->query('SELECT ' . Website::getDatabaseHandler()->fieldName('transakcja_id') . ', ' . Website::getDatabaseHandler()->fieldName('platnosc_id') . ' FROM ' . Website::getDatabaseHandler()->tableName('transakcja_platnosc_allegro') . ' WHERE ' . Website::getDatabaseHandler()->fieldName('transakcja_id') . ' = ' . Website::getDatabaseHandler()->quote($this->getId()) . ' AND ' . Website::getDatabaseHandler()->fieldName('platnosc_id') . ' = ' . Website::getDatabaseHandler()->quote($platnosc->getId()))->fetch() === FALSE)
		{
			Website::getDatabaseHandler()->query('INSERT INTO ' . Website::getDatabaseHandler()->tableName('transakcja_platnosc_allegro') . ' (' . Website::getDatabaseHandler()->fieldName('transakcja_id') . ', ' . Website::getDatabaseHandler()->fieldName('platnosc_id') . ') VALUES (' . Website::getDatabaseHandler()->quote($this->getId()) . ', ' . Website::getDatabaseHandler()->quote($platnosc->getId()) . ')');
		}
	}

	public function odwiazPlatnoscAllegro(PlatnoscAllegro $platnosc)
	{
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('Transakcja nie istnieje.');
		}
		if(!$platnosc->isLoaded())
		{
			throw new InvalidArgumentException('PlatnoscAllegro nie istnieje.');
		}
        Website::getDatabaseHandler()->query('DELETE FROM ' . Website::getDatabaseHandler()->tableName('transakcja_platnosc_allegro') . ' WHERE ' . Website::getDatabaseHandler()->fieldName('transakcja_id') . ' = ' . Website::getDatabaseHandler()->quote($this->getId()) . ' AND ' . Website::getDatabaseHandler()->fieldName('platnosc_id') . ' = ' . Website::getDatabaseHandler()->quote($platnosc->getId()));
	}

	public function getPowiazaniaPlatnoscBank()
	{
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('Transakcja nie istnieje.');
		}
		$listPlatnosc = new DatabaseList('PlatnoscBank');
		$filterTransakcja = new SQL_Filter(new SQL_Field('transakcja_id', 'transakcja_platnosc_bank'), SQL_Filter::EQUAL, $this->getId());
		$filterPlatnosc = new SQL_Filter(new SQL_Field('platnosc_id', 'transakcja_platnosc_bank'), SQL_Filter::EQUAL, new SQL_Field('id', 'platnosc_bank'));
		$filter = new SQL_Filter($filterTransakcja, SQL_Filter::CRITERIUM_AND, $filterPlatnosc);
		$listPlatnosc->setFilter($filter);
		return $listPlatnosc;
	}

	public function powiazPlatnoscBank(PlatnoscBank $platnosc)
	{
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('Transakcja nie istnieje.');
		}
		if(!$platnosc->isLoaded())
		{
			throw new InvalidArgumentException('PlatnoscBank nie istnieje.');
		}
		if(Website::getDatabaseHandler()->query('SELECT ' . Website::getDatabaseHandler()->fieldName('transakcja_id') . ', ' . Website::getDatabaseHandler()->fieldName('platnosc_id') . ' FROM ' . Website::getDatabaseHandler()->tableName('transakcja_platnosc_bank') . ' WHERE ' . Website::getDatabaseHandler()->fieldName('transakcja_id') . ' = ' . Website::getDatabaseHandler()->quote($this->getId()) . ' AND ' . Website::getDatabaseHandler()->fieldName('platnosc_id') . ' = ' . Website::getDatabaseHandler()->quote($platnosc->getId()))->fetch() === FALSE)
		{
			Website::getDatabaseHandler()->query('INSERT INTO ' . Website::getDatabaseHandler()->tableName('transakcja_platnosc_bank') . ' (' . Website::getDatabaseHandler()->fieldName('transakcja_id') . ', ' . Website::getDatabaseHandler()->fieldName('platnosc_id') . ') VALUES (' . Website::getDatabaseHandler()->quote($this->getId()) . ', ' . Website::getDatabaseHandler()->quote($platnosc->getId()) . ')');
		}
	}

	public function odwiazPlatnoscBank(PlatnoscBank $platnosc)
	{
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('Transakcja nie istnieje.');
		}
		if(!$platnosc->isLoaded())
		{
			throw new InvalidArgumentException('PlatnoscBank nie istnieje.');
		}
        Website::getDatabaseHandler()->query('DELETE FROM ' . Website::getDatabaseHandler()->tableName('transakcja_platnosc_bank') . ' WHERE ' . Website::getDatabaseHandler()->fieldName('transakcja_id') . ' = ' . Website::getDatabaseHandler()->quote($this->getId()) . ' AND ' . Website::getDatabaseHandler()->fieldName('platnosc_id') . ' = ' . Website::getDatabaseHandler()->quote($platnosc->getId()));
	}

	public function getPowiazaniaWiadomosc()
	{
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('Obiekt $this nie istnieje.');
		}
		$listWiadomosc = new DatabaseList('Wiadomosc');
		$filter = new SQL_Filter(new SQL_Field('transakcja_id'), SQL_Filter::EQUAL, $this->getId());
		$listWiadomosc->setFilter($filter);
		return $listWiadomosc;
	}

	public function powiazWiadomosc(Wiadomosc $wiadomosc)
	{
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('Obiekt $this nie istnieje.');
		}
		if(!$wiadomosc->isLoaded())
		{
			throw new InvalidArgumentException('Wiadomosc nie istnieje.');
		}
		$transakcjaWiadomosci = $wiadomosc->getTransakcja();
		if(!$transakcjaWiadomosci->isLoaded() || $transakcjaWiadomosci->getId() != $this->getId())
		{
			$wiadomosc->setTransakcja($this);
			$wiadomosc->save();
		}
	}

	public function odwiazWiadomosc(Wiadomosc $wiadomosc)
	{
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('Obiekt $this nie istnieje.');
		}
		if(!$wiadomosc->isLoaded())
		{
			throw new InvalidArgumentException('Wiadomosc nie istnieje.');
		}
		$transakcjaWiadomosci = $wiadomosc->getTransakcja();
		if($transakcjaWiadomosci->isLoaded() && $transakcjaWiadomosci->getId() == $this->getId())
		{
			$wiadomosc->setTransakcja(null);
			$wiadomosc->save();
		}
	}

	public function getPowiazaniaPrzesylkaOdebrana()
	{
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('Transakcja nie istnieje.');
		}
		$listPrzesylka = new DatabaseList('PrzesylkaOdebrana');
		$filterTransakcja = new SQL_Filter(new SQL_Field('transakcja_id', 'transakcja_przesylka_odebrana'), SQL_Filter::EQUAL, $this->getId());
		$filterPrzesylka = new SQL_Filter(new SQL_Field('przesylka_id', 'transakcja_przesylka_odebrana'), SQL_Filter::EQUAL, new SQL_Field('id', 'przesylka_odebrana'));
		$filter = new SQL_Filter($filterTransakcja, SQL_Filter::CRITERIUM_AND, $filterPrzesylka);
		$listPrzesylka->setFilter($filter);
		return $listPrzesylka;
	}

	public function powiazPrzesylkaOdebrana(PrzesylkaOdebrana $przesylka)
	{
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('Transakcja nie istnieje.');
		}
		if(!$przesylka->isLoaded())
		{
			throw new InvalidArgumentException('PrzesylkaOdebrana nie istnieje.');
		}
		if(Website::getDatabaseHandler()->query('SELECT ' . Website::getDatabaseHandler()->fieldName('transakcja_id') . ', ' . Website::getDatabaseHandler()->fieldName('przesylka_id') . ' FROM ' . Website::getDatabaseHandler()->tableName('transakcja_przesylka_odebrana') . ' WHERE ' . Website::getDatabaseHandler()->fieldName('transakcja_id') . ' = ' . Website::getDatabaseHandler()->quote($this->getId()) . ' AND ' . Website::getDatabaseHandler()->fieldName('przesylka_id') . ' = ' . Website::getDatabaseHandler()->quote($przesylka->getId()))->fetch() === FALSE)
		{
			Website::getDatabaseHandler()->query('INSERT INTO ' . Website::getDatabaseHandler()->tableName('transakcja_przesylka_odebrana') . ' (' . Website::getDatabaseHandler()->fieldName('transakcja_id') . ', ' . Website::getDatabaseHandler()->fieldName('przesylka_id') . ') VALUES (' . Website::getDatabaseHandler()->quote($this->getId()) . ', ' . Website::getDatabaseHandler()->quote($przesylka->getId()) . ')');
		}
	}

	public function odwiazPrzesylkaOdebrana(PrzesylkaOdebrana $przesylka)
	{
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('Transakcja nie istnieje.');
		}
		if(!$przesylka->isLoaded())
		{
			throw new InvalidArgumentException('PrzesylkaOdebrana nie istnieje.');
		}
        Website::getDatabaseHandler()->query('DELETE FROM ' . Website::getDatabaseHandler()->tableName('transakcja_przesylka_odebrana') . ' WHERE ' . Website::getDatabaseHandler()->fieldName('transakcja_id') . ' = ' . Website::getDatabaseHandler()->quote($this->getId()) . ' AND ' . Website::getDatabaseHandler()->fieldName('przesylka_id') . ' = ' . Website::getDatabaseHandler()->quote($przesylka->getId()));
	}

	public function getPowiazaniaPrzesylkaNadana()
	{
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('Transakcja nie istnieje.');
		}
		$listPrzesylka = new DatabaseList('PrzesylkaNadana');
		$filterTransakcja = new SQL_Filter(new SQL_Field('transakcja_id', 'transakcja_przesylka_nadana'), SQL_Filter::EQUAL, $this->getId());
		$filterPrzesylka = new SQL_Filter(new SQL_Field('przesylka_id', 'transakcja_przesylka_nadana'), SQL_Filter::EQUAL, new SQL_Field('id', 'przesylka_nadana'));
		$filter = new SQL_Filter($filterTransakcja, SQL_Filter::CRITERIUM_AND, $filterPrzesylka);
		$listPrzesylka->setFilter($filter);
		return $listPrzesylka;
	}

	public function powiazPrzesylkaNadana(PrzesylkaNadana $przesylka)
	{
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('Transakcja nie istnieje.');
		}
		if(!$przesylka->isLoaded())
		{
			throw new InvalidArgumentException('PrzesylkaNadana nie istnieje.');
		}
		if(Website::getDatabaseHandler()->query('SELECT ' . Website::getDatabaseHandler()->fieldName('transakcja_id') . ', ' . Website::getDatabaseHandler()->fieldName('przesylka_id') . ' FROM ' . Website::getDatabaseHandler()->tableName('transakcja_przesylka_nadana') . ' WHERE ' . Website::getDatabaseHandler()->fieldName('transakcja_id') . ' = ' . Website::getDatabaseHandler()->quote($this->getId()) . ' AND ' . Website::getDatabaseHandler()->fieldName('przesylka_id') . ' = ' . Website::getDatabaseHandler()->quote($przesylka->getId()))->fetch() === FALSE)
		{
			Website::getDatabaseHandler()->query('INSERT INTO ' . Website::getDatabaseHandler()->tableName('transakcja_przesylka_nadana') . ' (' . Website::getDatabaseHandler()->fieldName('transakcja_id') . ', ' . Website::getDatabaseHandler()->fieldName('przesylka_id') . ') VALUES (' . Website::getDatabaseHandler()->quote($this->getId()) . ', ' . Website::getDatabaseHandler()->quote($przesylka->getId()) . ')');
		}
	}

	public function odwiazPrzesylkaNadana(PrzesylkaNadana $przesylka)
	{
		if(!$this->isLoaded())
		{
			throw new InvalidArgumentException('Transakcja nie istnieje.');
		}
		if(!$przesylka->isLoaded())
		{
			throw new InvalidArgumentException('PrzesylkaNadana nie istnieje.');
		}
        Website::getDatabaseHandler()->query('DELETE FROM ' . Website::getDatabaseHandler()->tableName('transakcja_przesylka_nadana') . ' WHERE ' . Website::getDatabaseHandler()->fieldName('transakcja_id') . ' = ' . Website::getDatabaseHandler()->quote($this->getId()) . ' AND ' . Website::getDatabaseHandler()->fieldName('przesylka_id') . ' = ' . Website::getDatabaseHandler()->quote($przesylka->getId()));
	}


// atrybuty
	public function getNumerTransakcji()
	{
		return $this->getId();
	}

	public function setNumerTransakcji($value)
	{
		$this->setID($value);
	}

	public function getIloscSztuk()
	{
		return $this->data['ilosc_sztuk'];
	}
	
	public function setIloscSztuk($value)
	{
		if($value != (int) $value || $value <= 0)
		{
			throw new InvalidArgumentException('Nie poprawny format ilosc sztuk.');
		}
		$this->data['ilosc_sztuk'] = $value;
	}

	public function getDataRozpoczecia()
	{
		return $this->data['data_rozpoczecia'];
	}
	
	public function setDataRozpoczecia($value)
	{
		if($value != (int) $value || $value < 0)
		{
			throw new InvalidArgumentException('Nie poprawny format daty rozpoczecia.');
		}
		$this->data['data_rozpoczecia'] = $value;
	}

	public function getDataZakonczenia()
	{
		return $this->data['data_zakonczenia'];
	}

	public function setDataZakonczenia($value)
	{
		if($value != (int) $value || $value < 0)
		{
			throw new InvalidArgumentException('Nie poprawny format daty zakonczenia.');
		}
		$this->data['data_zakonczenia'] = $value;
	}

	public function getStatusTransakcji()
	{
		return $this->data['status_transakcji'];
	}

	public function setStatusTransakcji($value)
	{
		if(!StatusTransakcji::isValidValue($value))
		{
			throw new InvalidArgumentException('Nie poprawna wartosc statusu transakcji.');
		}
		$this->data['status_transakcji'] = $value;
	}
}