<?php
if(!defined('INITIALIZED'))
	die('Brak dostepu.');

class Wiadomosc extends Model
{
	protected static $table = 'wiadomosc';
	protected static $fields = array('transakcja_id', 'zrodlo_wiadomosci', 'nadawca', 'adresat', 'tytul', 'tresc', 'data_otrzymania');

    public function __construct($id = null)
    {
		if($id != null && $id != 0)
			$this->load($id, 'id');
    }

	public static function getFieldsList()
	{
		if(get_parent_class() && method_exists(get_parent_class(), 'getFieldsList'))
		{
			return array_merge(parent::getFieldsList(), self::$fields);
		}
		else
		{
			return self::$fields;
		}
	}

	public function load($id)
	{
		$search_string = $this->getDatabaseHandler()->fieldName('id') . ' = ' . $this->getDatabaseHandler()->quote($id);
		$fieldsArray = array();
		foreach(self::$fields as $fieldName)
		{
			$fieldsArray[$fieldName] = $this->getDatabaseHandler()->fieldName($fieldName);
		}
		$this->data = $this->getDatabaseHandler()->query('SELECT ' . implode(', ', $fieldsArray) . ' FROM ' . $this->getDatabaseHandler()->tableName(self::$table) . ' WHERE ' . $search_string)->fetch();
	}

	public function save($forceInsert = false)
	{
		if(!isset($this->data['id']) || $forceInsert)
		{
			$keys = array();
			$values = array();
			foreach(self::$fields as $key)
				if($key != 'id')
				{
					$keys[] = $this->getDatabaseHandler()->fieldName($key);
					$values[] = $this->getDatabaseHandler()->quote($this->data[$key]);
				}
			$this->getDatabaseHandler()->query('INSERT INTO ' . $this->getDatabaseHandler()->tableName(self::$table) . ' (' . implode(', ', $keys) . ') VALUES (' . implode(', ', $values) . ')');
			$this->setID($this->getDatabaseHandler()->lastInsertId());
		}
		else
		{
			$updates = array();
			foreach(self::$fields as $key)
				if($key != 'id')
					$updates[] = $this->getDatabaseHandler()->fieldName($key) . ' = ' . $this->getDatabaseHandler()->quote($this->data[$key]);
			$this->getDatabaseHandler()->query('UPDATE ' . $this->getDatabaseHandler()->tableName(self::$table) . ' SET ' . implode(', ', $updates) . ' WHERE ' . $this->getDatabaseHandler()->fieldName('id') . ' = ' . $this->getDatabaseHandler()->quote($this->data['id']));
		}
	}

    public function delete()
    {
        $this->getDatabaseHandler()->query('DELETE FROM ' . $this->getDatabaseHandler()->tableName(self::$table) . ' WHERE ' . $this->getDatabaseHandler()->fieldName('id') . ' = ' . $this->getDatabaseHandler()->quote($this->data['id']));

        unset($this->data['id']);
    }


// powiazania
	public function getTransakcja()
	{
		return new Transakcja($this->data['transakcja_id']);
	}

	public function setTransakcja($value)
	{
		// $value moze byc null/0, powiazanie moze nie istniec
		$valueToSave = 0
		if($value === null || $value === 0)
		{
			$valueToSave = 0;
		}
		elseif($value instanceof Transakcja)
		{
			if(!$value->isLoaded())
			{
				throw new InvalidArgumentException('Transakcja nie istnieje.');
			}
			else
			{
				$valueToSave = $value->getId();
			}
		}
		else
		{
			throw new InvalidArgumentException('Argument musi byc "null", "0" lub instancja "Transakcja".');
		}
		$this->data['transakcja_id'] = $valueToSave;
	}


// atrybuty
	public function getId()
	{
		return $this->data['id'];
	}

	public function setZrodloWiadomosci($value)
	{
		if(!ZrodloWiadomosci::isValidValue($value))
		{
			throw new InvalidArgumentException('Nie poprawna wartosc zrodla wiadomosci.');
		}
		$this->data['zrodlo_wiadomosci'] = $value;
	}

	public function getNadawca()
	{
		return $this->data['nadawca'];
	}

	public function setNadawca($value)
	{
		if($value != (string) $value)
		{
			throw new InvalidArgumentException('Nie poprawny format nadawcy.');
		}
		$this->data['nadawca'] = $value;
	}

	public function getAdresat()
	{
		return $this->data['adresat'];
	}

	public function setAdresat($value)
	{
		if($value != (string) $value)
		{
			throw new InvalidArgumentException('Nie poprawny format adresata.');
		}
		$this->data['adresat'] = $value;
	}
	
	public function getTytul()
	{
		return $this->data['tytul'];
	}

	public function setTytul($value)
	{
		if($value != (string) $value)
		{
			throw new InvalidArgumentException('Nie poprawny format tytulu.');
		}
		$this->data['tytul'] = $value;
	}
	
	public function getTresc()
	{
		return $this->data['tresc'];
	}

	public function setTresc($value)
	{
		if($value != (string) $value)
		{
			throw new InvalidArgumentException('Nie poprawny format tresci.');
		}
		$this->data['tresc'] = $value;
	}
	
	public function getDataOtrzymania()
	{
		return $this->data['data_otrzymania'];
	}

	public function setDataOtrzymania($value)
	{
		if($value != (int) $value || $value <= 0)
		{
			throw new InvalidArgumentException('Nie poprawny format daty otrzymania.');
		}
		$this->data['data_otrzymania'] = $value;
	}
}