<?php
if(!defined('INITIALIZED'))
	die('Brak dostepu.');

class RequiredVariable 
{
	const TYPE_NUMBER = 1;
	const TYPE_FLOAT = 2;
	const TYPE_INTEGER = 3;
	const TYPE_STRING = 4;

	private $error;
	private $name;
	private $type;
	private $defaultValue;
	private $allowedValues;
	private $regularExpression;

	public function __construct($name, $type, $defaultValue = null, $allowedValues = null, $regularExpression = null)
	{
		$this->name = $name;
		$this->type = $type;
		$this->defaultValue = $defaultValue;
		$this->allowedValues = $allowedValues;
		$this->regularExpression = $regularExpression;
	}

	public function getName()
	{
		return $this->name;
	}

	public function setName($name)
	{
		$this->name = $name;
	}

	public function setType($type)
	{
		$this->type = $type;
	}

	public function hasDefaultValue()
	{
		return isset($this->defaultValue) && $this->defaultValue !== null;
	}

	public function getDefaultValue()
	{
		return $this->defaultValue;
	}

	public function setDefaultValue($defaultValue)
	{
		$this->defaultValue = $defaultValue;
	}

	public function hasAllowedValues()
	{
		return isset($this->allowedValues) && $this->allowedValues !== null;
	}

	public function getAllowedValues()
	{
		return $this->allowedValues;
	}

	public function setAllowedValues($allowedValues)
	{
		$this->allowedValues = $allowedValues;
	}

	public function hasRegularExpression()
	{
		return isset($this->regularExpression) && $this->regularExpression !== null;
	}

	public function setRegularExpression($regularExpression)
	{
		$this->regularExpression = $regularExpression;
	}

	public function getRegularExpression()
	{
		return $this->regularExpression;
	}

	public function getError()
	{
		return $this->error;
	}

	public function validate($variable)
	{
		if($this->hasAllowedValues() && !in_array($variable, $this->getAllowedValues()))
		{
			$this->error = 'Value "' . htmlspecialchars((string) $variable) . '" is not in allowed values array.';
			return false;
		}
		switch($this->type)
		{
			case self::TYPE_NUMBER:
				if(!is_numeric($variable))
				{
					$this->error = 'Value "' . htmlspecialchars((string) $variable) . '" is not number.';
					return false;
				}
				break;
			case self::TYPE_FLOAT:
				if((string) $variable != (string) ((float) $variable))
				{
					$this->error = 'Value "' . htmlspecialchars((string) $variable) . '" is not float.';
					return false;
				}
				break;
			case self::TYPE_INTEGER:
				if((string) $variable != (string) ((int) $variable))
				{
					$this->error = 'Value "' . htmlspecialchars((string) $variable) . '" is not integer.';
					return false;
				}
				break;
			case self::TYPE_STRING:
				if($variable != (string) $variable)
				{
					$this->error = 'Value "' . htmlspecialchars((string) $variable) . '" is not string.';
					return false;
				}
				break;
		}
		return true;
	}

}