<?php
if(!defined('INITIALIZED'))
	die('Brak dostepu.');

class Website
{
	public static $websiteConfig;
	public static $SQL;

	public static function turnOnAutoClassLoading()
	{
		function autoLoadClass($class)
		{
			if (file_exists(HOME . DS . 'application' . DS . 'models' . DS . strtolower($class) . '.php'))
			{
				require_once(HOME . DS . 'application' . DS . 'models' . DS . strtolower($class) . '.php');
			}
			else if (file_exists(HOME . DS . 'application' . DS . 'controllers' . DS . strtolower($class) . '.php'))
			{
				include(HOME . DS . 'application' . DS . 'controllers'  . DS . strtolower($class) . '.php');
			}
			else if (file_exists(HOME . DS . 'application' . DS . 'enums' . DS . strtolower($class) . '.php'))
			{
				include(HOME . DS . 'application' . DS . 'enums'  . DS . strtolower($class) . '.php');
			}
			else if (file_exists(HOME . DS . 'system' . DS . 'classes' . DS . strtolower($class) . '.php'))
			{
				require_once(HOME . DS . 'system' . DS . 'classes' . DS . strtolower($class) . '.php');
			}
		}
		spl_autoload_register('autoLoadClass');
	}

	public static function configureDatabaseConnection()
	{
		if(self::getWebsiteConfig()->isSetKey('sqlType'))
		{
			if(self::getWebsiteConfig()->getValue('sqlType') == 'mysql')
			{
				self::setDatabaseDriver(Database::DB_MYSQL);

				if(self::getWebsiteConfig()->isSetKey('sqlHost'))
					self::getDatabaseHandler()->setDatabaseHost(self::getWebsiteConfig()->getValue('sqlHost'));
				else
					throw new CriticException('There is no key <b>sqlHost</b> in website config.');

				if(self::getWebsiteConfig()->isSetKey('sqlPort'))
					self::getDatabaseHandler()->setDatabasePort(self::getWebsiteConfig()->getValue('sqlPort'));
				else
					throw new CriticException('There is no key <b>sqlPort</b> in website config.');

				if(self::getWebsiteConfig()->isSetKey('sqlDatabaseName'))
					self::getDatabaseHandler()->setDatabaseName(self::getWebsiteConfig()->getValue('sqlDatabaseName'));
				else
					throw new CriticException('There is no key <b>sqlDatabaseName</b> in website config.');

				if(self::getWebsiteConfig()->isSetKey('sqlUser'))
					self::getDatabaseHandler()->setDatabaseUsername(self::getWebsiteConfig()->getValue('sqlUser'));
				else
					throw new CriticException('There is no key <b>sqlUser</b> in website config.');

				if(self::getWebsiteConfig()->isSetKey('sqlPass'))
					self::getDatabaseHandler()->setDatabasePassword(self::getWebsiteConfig()->getValue('sqlPass'));
				else
					throw new CriticException('There is no key <b>sqlPass</b> in website config.');
			}
			elseif(self::getWebsiteConfig()->getValue('sqlType') == 'sqlite')
			{
				self::setDatabaseDriver(Database::DB_SQLITE);
				if(self::getWebsiteConfig()->isSetKey('sqliteFile'))
					self::getDatabaseHandler()->setDatabaseFile(self::getWebsiteConfig()->getValue('sqliteFile'));
				else
					throw new CriticException('There is no key <b>sqliteFile</b> in website config.');
			}
			else
				throw new CriticException('Database error. Unknown database <b>sqlType</b> in <b>config</b> . Must be equal to: "<b>mysql</b>" or "<b>sqlite</b>". Now is: "<b>' . self::getWebsiteConfig()->getValue(SERVERCONFIG_SQL_TYPE) . '</b>"');
		}
	}

	public static function setDatabaseDriver($value)
	{
		self::$SQL = null;

		switch($value)
		{
			case Database::DB_MYSQL:
				self::$SQL = new Database_MySQL();
				break;
			case Database::DB_SQLITE:
				self::$SQL = new Database_SQLite();
				break;
		}
	}

	public static function getDatabaseHandler()
	{
		if(isset(self::$SQL))
			return self::$SQL;
		else
			throw new CriticException('Class::Website - getDatabaseHandler(), database driver not set.');
	}	

	public static function loadWebsiteConfig()
	{
		self::$websiteConfig = new ConfigPHP('./config.php');
	}

	public static function getWebsiteConfig()
	{
		if(!isset(self::$websiteConfig))
			self::loadWebsiteConfig();

		return self::$websiteConfig;
	}

	public static function getConfig($fileNameArray)
	{
		$fileName = implode('_', $fileNameArray);

		if(Functions::isValidFolderName($fileName))
		{
			$_config = new ConfigPHP('./application/config/' . $fileName . '.php');
			return $_config;
		}
		else
			throw new CriticException(__CLASS__ . '::' . __METHOD__ . ' - Invalid folder/file name: <b>' . htmlspecialchars('./application/config/' . htmlspecialchars($fileName) . '.php') . '</b>');
	}

	public static function getFileContents($path)
	{
		$file = file_get_contents($path);

		if($file === false)
			throw new CriticException(__CLASS__ . '::' . __METHOD__ . ' - Cannot read from file: <b>' . htmlspecialchars($path) . '</b>');

		return $file;
	}

	public static function putFileContents($path, $data, $append = false)
	{
		if($append)
			$status = file_put_contents($path, $data, FILE_APPEND);
		else
			$status = file_put_contents($path, $data);

		if($status === false)
			throw new CriticException(__CLASS__ . '::' . __METHOD__ . ' - Cannot write to: <b>' . htmlspecialchars($path) . '</b>');

		return $status;
	}

	public static function deleteFile($path)
	{
		unlink($path);
	}

	public static function fileExists($path)
	{
		return file_exists($path);
	}

	public static function getTime()
	{
		return $_SERVER['REQUEST_TIME'];
	}

	public static function redirect($controller, $action)
	{
		$link = Functions::link($controller, $action);
		if(!headers_sent())
			header('Location: ' . $link);
		echo $text;
		echo 'Page should redirect you to ' . $link .'.<br />If it doesn\'t then press on link:<br /><a href="' . $link . '">' . $link . '</a>';
		exit;
	}
}